<?php

/******************************************************************************
 * INITIALIZE
 *****************************************************************************/

if ( ! defined( 'SIMPLE_AMAZON_PLUGIN_DIR' ) )
	define( 'SIMPLE_AMAZON_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . plugin_basename( dirname( __FILE__ ) ) );

$simple_amazon_config = array(
	'AWSAccessKeyId'=> '',						// DevToken
	'private_key'	=> '',	// SecretKey
	'litephp_path'	=> 'Lite.php',									// Lite.phpのpath
	'cache_dir'		=> SIMPLE_AMAZON_PLUGIN_DIR. '/cache/',			// cacheディレクトリのpath
	'cache_time'	=> 60*60*24										// cacheの有効時間(秒単位)
);


/******************************************************************************
 * MAIN CLASS
 *****************************************************************************/
class GetSimpleAmazonXmlParse {

	var $AssociatesID;
	var $asin;
	var $ResponseGroup;

	/**
	 * The Constructor
	 * 
	 * @param none
	 * @return Object reference
	 */

	function GetSimpleAmazonXmlParse() {

//		global $simple_amazon_config;

	}

	/**
	 * Get ECS XML.
	 * 
	 * @param $asin (ASIN)
	 * @param $ResponseGroup (Small / Medium / Large : 情報量)
	 * @param $Page (詳細情報ページ)
	 */
	function getamazonxml( $AssociatesID, $asin, $ResponseGroup ) {

		global $simple_amazon_config;

		$method = "GET";
		$host = "ecs.amazonaws.jp";
		$uri = "/onca/xml";

		$params = array(
			'Service'			=> 'AWSECommerceService',
			'AssociateTag'		=> 'icoro-22',
			'AWSAccessKeyId'	=> $simple_amazon_config['AWSAccessKeyId'],
			'Timestamp'			=> gmdate("Y-m-d\TH:i:s\Z"),
			'Version'			=> '2009-07-13',
			'ContentType'		=> 'text/xml',
			'Operation'			=> 'ItemLookup',
			'MerchantId'		=> 'All',
			'Condition'			=> 'All'
		);

		if( $AssociatesID != '' ) $params['AssociateTag'] = $AssociatesID;
		$params['ItemId']			= $asin;
		$params['ResponseGroup']	= $ResponseGroup;

		// sort the parameters
		ksort($params);

		// create the canonicalized query
		$canonicalized_query = array();
		foreach ($params as $param=>$value) {
			$param = str_replace("%7E", "~", rawurlencode($param));
			$value = str_replace("%7E", "~", rawurlencode($value));
			$canonicalized_query[] = $param."=".$value;
		}
		$canonicalized_query = implode("&", $canonicalized_query);

		// create the string to sign
		$string_to_sign = $method."\n".$host."\n".$uri."\n".$canonicalized_query;

		// calculate HMAC with SHA256 and base64-encoding
		$signature = base64_encode(hash_hmac("sha256", $string_to_sign, $simple_amazon_config['private_key'], true));

		// create request
		$xmlFeed = "http://".$host.$uri."?".$canonicalized_query."&Signature=".$signature;

		// --- Include the cache package ---
		// IMPORTANT - enter the path to Lite.php
		include_once( $simple_amazon_config['litephp_path'] );

		// --- Set an ID for this cache ---
		$id = $params['ItemId'];


		/**
		* Cache options
		* "lifeTime" is in seconds, so 1 hour would be 60*60*1
		*
		* IMPORTANT - enter the path to your cache directory (a new directory with full permissions)
		*/
		$options = array(
//			"cacheDir" => "./cache/",
			'cacheDir' => $simple_amazon_config['cache_dir'],
			'lifeTime' => $simple_amazon_config['cache_time']
			);
		
		$objCache = new Cache_Lite($options);

		// Check to see if there is a valid cache of xml

		if ($xmldata = $objCache->get($id)) {  // there is a cache, so parse cached xml
//			echo "<!-- read cache -->";
		}else{
//			echo "<!-- read feed -->";
			if( ! $xmldata = @file_get_contents($xmlFeed) ) return false;
			$objCache->save($xmldata, $id);
		}
		$parsedata = simplexml_load_string($xmldata);
		return $parsedata;
	}

}


/******************************************************************************
 * cacheを削除するクラス
 *****************************************************************************/
class ClearCacheFiles {

	function ClearCaches() {}
	function clear() {

		global $simple_amazon_config;

		include_once( $simple_amazon_config['litephp_path'] );
		$options = array( 'cacheDir' => $simple_amazon_config['cache_dir'] );
		
		$objCache = new Cache_Lite($options);
		$objCache->clean();

	}

}

/******************************************************************************
 * ISBN13とISBN10を相互に変換するクラス
 *****************************************************************************/
class CalcISBNLibrary {

	function calc_chkdgt_mod10( $val ){
		$f = 0;
		$g = 0;
		$k = 0;

		$mod_res = explode( ',',chunk_split( $val, 1, ',' ) );
		for( $ii=count( $mod_res )-1; $ii>-1; $ii-- ){
			$x=intval( $mod_res[$ii] );
			if( $f == 0 ){
				$k += $x;
				$f = 1;
			} else {
				$g += $x;
				$f = 0;
			}
		}
		$chkdgt = substr( strval( 10-intval( substr( strval( $g*3 + $k ), -1 ) ) ),-1 );
		return $val.$chkdgt;
	}

	function calc_chkdgt_isbn10( $val ){
		$g = 0;

		$mod_res = explode( ',',chunk_split( $val, 1, ',' ) );
		for( $ii=count( $mod_res )-1; $ii>-1; $ii-- ){
			$x=intval( $mod_res[$ii] );
			$g += $x*( 11-( $ii+1 ));
		}

		$checksum = (( (int)( $g/11 ) )+1)*11 - $g;

		if( $checksum == 11 ){
			$chkdgt = 0;
		} elseif( $checksum == 10 ){
			$chkdgt = 'X';
		} else {
			$chkdgt = $checksum;
		}

		return $val.$chkdgt;
	}

}
?>